@@ -23,7 +23,7 @@
 #' @export
 #' @return a 'gtsummary' table
 #'
-#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed("car")
+#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed(c("car", "parameters"))
 #' tbl <-
 #'   lm(time ~ ph.ecog + sex, survival::lung) |>
 #'   tbl_regression(label = list(ph.ecog = "ECOG Score", sex = "Sex"))
@@ -118,7 +118,7 @@ add_significance_stars <- function(x,
     unlist() |>
     paste(collapse = "; ")
 
-  x <- modify_footnote_header(x, footnote = p_footnote, columns = any_of(pattern_cols[1]))
+  x <- modify_footnote_header(x, footnote = p_footnote, columns = any_of(pattern_cols[1]), replace = FALSE)
 
   # adding stars column --------------------------------------------------------
   thresholds <- union(thresholds, 0L)
