@@ -53,6 +53,7 @@
 #'   In rarer cases, you may need to define/override the typical denominators.
 #'   In these cases, pass an integer or a data frame. Refer to the
 #'   [`?cards::ard_tabulate(denominator)`][cards::ard_tabulate] help file for details.
+#'   When a data frame is passed, this data frame is used to calculate header counts.
 #' @param include ([`tidy-select`][dplyr::dplyr_tidy_select])\cr
 #'   Variables to include in the summary table. Default is `everything()`.
 #'
@@ -214,7 +215,22 @@ tbl_summary <- function(data,
   if (is.character(percent)) {
     percent <- arg_match(percent, values = c("column", "row", "cell"))
   }
-  else if (!is.data.frame(percent) && !is_integerish(percent)) {
+  else if (is.data.frame(percent)) {
+    if (!is_empty(by) && !by %in% names(percent)) {
+      cli::cli_abort(
+        "The {.cls data.frame} passed in the {.arg percent} argument must contain the {.val {by}} column.",
+        call = get_cli_abort_call()
+      )
+    }
+    if (!is_empty(by) && !identical(class(data[[by]]), class(percent[[by]]))) {
+      cli::cli_abort(
+        "The class of the {.val {by}} column in {.arg data} data frame ({.cls {class(data[[by]])}})
+          must match the class in the {.arg percent} data frame ({.cls {class(percent[[by]])}}) .",
+        call = get_cli_abort_call()
+      )
+    }
+  }
+  else if (!is_integerish(percent)) {
     cli::cli_abort(
       "The {.arg percent} argument must be one of {.val {c('column', 'row', 'cell')}} ({.emph the most common input}),
          or a {.cls data.frame} or {.cls integer}; not a {.obj_type_friendly {percent}}.",
@@ -375,12 +391,14 @@ tbl_summary <- function(data,
                          stat_label = ~ default_stat_labels()
       ),
       # adding total N
-      cards::ard_total_n(data),
+      cards::ard_total_n(
+        data = case_switch(is.data.frame(percent) ~ percent, .default = data)
+      ),
       # tabulate by variable for header stats
       case_switch(
         !is_empty(by) ~
           cards::ard_tabulate(
-            data,
+            data = case_switch(is.data.frame(percent) ~ percent, .default = data),
             variables = all_of(by),
             stat_label = ~ default_stat_labels()
           ),
