@@ -1,5 +1,7 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("survey", "withr")) && is_pkg_installed("broom", ref = "cardx"))
+skip_if_pkg_not_installed(c("survey", "withr"))
+skip_if_pkg_not_installed("broom", ref = "cardx")
+
 svy_trial <- survey::svydesign(~1, data = trial, weights = ~1)
 
 test_that("add_ci(method) with no `by`", {
@@ -797,4 +799,3 @@ test_that("add_ci.tbl_svysummary() ordering for factors", {
       dplyr::pull(ci_stat_2)
   )
 })
-
