@@ -1,8 +1,8 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c(
-  "broom", "broom.helpers", "lme4", "smd",
-  "effectsize", "emmeans"
-), ref = "cardx"))
+skip_if_pkg_not_installed(
+  c("broom", "broom.helpers", "lme4", "smd", "effectsize", "emmeans"),
+  ref = "cardx"
+)
 
 test_that("add_difference.tbl_summary() works with basic usage", {
   expect_error(
@@ -51,7 +51,7 @@ test_that("add_difference.tbl_summary() works with basic usage", {
 })
 
 test_that("add_difference.tbl_summary(tests = 'emmeans')", {
-  skip_if_not(is_pkg_installed("emmeans", ref = "cardx"))
+  skip_if_pkg_not_installed("emmeans", ref = "cardx")
   tbl1 <-
     trial |>
     tbl_summary(
@@ -67,7 +67,7 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
         -cards::all_ard_variables(),
         -fmt_fun
       ),
-    cardx::ard_emmeans_mean_difference(
+    cardx::ard_emmeans_contrast(
       data = trial,
       formula = ttdeath ~ trt,
       method = "lm",
@@ -96,7 +96,7 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
         -cards::all_ard_variables(),
         -fmt_fun
       ),
-    cardx::ard_emmeans_mean_difference(
+    cardx::ard_emmeans_contrast(
       data = trial,
       formula = ttdeath ~ trt + (1 | grade),
       method = "lmer",
@@ -126,7 +126,7 @@ test_that("add_difference.tbl_summary(tests = 'emmeans')", {
         -cards::all_ard_variables(),
         -fmt_fun
       ),
-    cardx::ard_emmeans_mean_difference(
+    cardx::ard_emmeans_contrast(
       data = trial,
       formula = response ~ trt,
       method = "glm",
