@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("car", "broom", "broom.helpers", "parameters", "survey")))
+skip_if_pkg_not_installed(c("car", "broom", "broom.helpers", "parameters", "survey"))
 
 test_that("add_variable_group_header() works", {
   expect_silent(
