@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("flextable", "broom.helpers")))
+skip_if_pkg_not_installed(c("flextable", "broom.helpers"))
 
 my_tbl_summary <- trial |>
   select(trt, age, death) |>
@@ -28,7 +28,8 @@ test_that("as_flex_table works with standard use", {
 })
 
 test_that("as_flex_table works with tbl_survfit", {
-  skip_if_not(is_pkg_installed("survival"))
+  skip_if_pkg_not_installed("survival")
+
   fit1 <- survival::survfit(survival::Surv(ttdeath, death) ~ trt, trial)
   tbl <- tbl_survfit(fit1, times = c(12, 24), label_header = "{time} Months")
 
@@ -43,7 +44,7 @@ test_that("as_flex_table works with tbl_survfit", {
 })
 
 test_that("as_flex_table works with tbl_merge", {
-  skip_if_not(is_pkg_installed("survival"))
+  skip_if_pkg_not_installed("survival")
 
   t1 <- glm(response ~ trt + grade + age, trial, family = binomial) |>
     tbl_regression(exponentiate = TRUE)
