@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("survival", "broom.helpers")))
+skip_if_pkg_not_installed(c("survival", "broom.helpers"))
 
 # inline_text.tbl_summary tests ------------------------------------------------
 test_inline1 <- trial |> tbl_summary()
@@ -274,7 +274,7 @@ test_that("inline_text.tbl_cross() messaging", {
   )
 })
 
-# skip_if_not(broom.helpers::.assert_package("survey", pkg_search = "gtsummary", boolean = TRUE))
+# skip_if_pkg_not_installed("survey")
 #
 # # inline_text.tbl_svysummary tests --------------
 # test_inline1 <- trial %>%
@@ -341,7 +341,7 @@ test_that("inline_text.tbl_cross() messaging", {
 # })
 
 # test_that("inline_text.tbl_svysummary: no errors with empty string selection", {
-#   skip_if_not(broom.helpers::.assert_package("survey", pkg_search = "gtsummary", boolean = TRUE))
+#   skip_if_pkg_not_installed("survey")
 #   expect_error(
 #     trial %>%
 #       select(grade) %>%
