@@ -27,4 +27,20 @@ test_that("modify_post_fmt_fun() works", {
       getElement("table_styling") |>
       getElement("post_fmt_fun")
   )
+
+
+  # no errors after tables with modify_post_fmt_fun() are stacked
+  expect_silent(
+    tbl_strata_nested_stack(
+      trial,
+      strata = trt,
+      .tbl_fun = ~ .x |>
+        tbl_summary(include = response,) |>
+        modify_header(stat_0 = "**Overall**") |>
+        modify_post_fmt_fun(
+          fmt_fun = ~ ifelse(. == "0 (0.0%)", "0", .),
+          columns = all_stat_cols()
+        )
+    )
+  )
 })
