@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("withr"))
+skip_if_pkg_not_installed("withr")
 
 trial2 <- trial |>
   mutate(id = rep(1:50, length.out = nrow(trial)))
@@ -42,6 +42,19 @@ test_that("tbl_hierarchical(denominator) works properly", {
     error = TRUE,
     tbl_hierarchical(data = trial2, variables = trt, denominator = "test", id = id)
   )
+
+
+  # check error message when class of `by` column does not match
+  expect_snapshot(
+    error = TRUE,
+    tbl_hierarchical(
+      data = cards::ADAE,
+      by = TRTA,
+      variables = AEDECOD,
+      denominator = cards::ADSL |> dplyr::mutate(TRTA = factor(TRTA)),
+      id = USUBJID
+    )
+  )
 })
 
 # tbl_hierarchical(include) ------------------------------------------------------------
@@ -151,7 +164,7 @@ test_that("tbl_hierarchical(digits) works properly", {
     digits = grade ~ list(n = label_style_number(digits = 1, decimal.mark = ","), p = 3)
   )
   expect_snapshot(res |> as.data.frame())
-  expect_equal(res$table_body$stat_0[1], "36 (68%)")
+  expect_equal(res$table_body$stat_0[1], "36 (18%)")
 
   # testing passing vector
   expect_equal(
@@ -162,7 +175,7 @@ test_that("tbl_hierarchical(digits) works properly", {
       as.data.frame(col_labels = FALSE) |>
       dplyr::pull(stat_0) |>
       dplyr::last(),
-    "18.00 (100.00%)"
+    "18.00 (9.00%)"
   )
   expect_equal(
     tbl_hierarchical(
@@ -172,10 +185,9 @@ test_that("tbl_hierarchical(digits) works properly", {
       as.data.frame(col_labels = FALSE) |>
       dplyr::pull(stat_0) |>
       dplyr::last(),
-    "18 (100.00%)"
+    "18 (9.00%)"
   )
 
-
   # errors thrown when bad digits argument passed
   expect_snapshot(
     error = TRUE,
